@@ -1,7 +1,7 @@
 package Complete::Path;
 
-our $DATE = '2016-04-13'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $DATE = '2016-06-17'; # DATE
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -194,12 +194,12 @@ sub complete_path {
             #say "D:  intdir list($dir)";
             my $listres = $list_func->($dir, $intdir, 1);
             next unless $listres && @$listres;
-            #use DD; dd $listres;
+            #use DD; say "D: list res=", DD::dump($listres);
             my $matches = Complete::Util::complete_array_elem(
                 word => $intdir, array => $listres,
             );
             my $exact_matches = [grep {
-                length($intdir) eq length($_)
+                $_ eq $intdir || $_ eq $intdir_with_path_sep
             } @$matches];
             #use Data::Dmp; say "D: word=<$intdir>, matches=", dmp($matches), ", exact_matches=", dmp($exact_matches);
 
@@ -210,7 +210,7 @@ sub complete_path {
             # to 'a' because the candidates are 'a/foo' and 'and/foo' (it will
             # use the shortest common string which is 'a').
             #say "D:  num_exact_matches: ", scalar @$exact_matches;
-            if ($exp_im_path && @$exact_matches == 1) {
+            if (!$exp_im_path || @$exact_matches == 1) {
                 $matches = $exact_matches;
             }
 
@@ -307,7 +307,7 @@ Complete::Path - Complete path
 
 =head1 VERSION
 
-This document describes version 0.22 of Complete::Path (from Perl distribution Complete-Path), released on 2016-04-13.
+This document describes version 0.23 of Complete::Path (from Perl distribution Complete-Path), released on 2016-06-17.
 
 =head1 DESCRIPTION
 
